import { defineStore } from 'pinia'
import router from '@/router'

export const useUserStore = defineStore('user', {
	state: (): auth.AuthUser => ({
		mobile: '',
		email: '',
		fullName: '',
		password: '',
		permissions: [],
		roles: [],
		sex: 'FEMALE',
		token: '',
		refreshToken: '',
		userName: '',
	}),
	getters: {
		isAdmin(state) {
			return state.roles.includes('admin')
		},
		isLogin(state) {
			return state.token && state.refreshToken
		},
		getPermission(state) {
			return state.permissions
		},
	},
	actions: {
		refreshUserInfo(user: auth.AuthUser) {
			Object.assign(this, user)
		},
		userLogin(user: auth.AuthUser) {
			Object.assign(this, user)
			// 过了路由的地址
			// router.addRoute

			router.push({ path: '/admin/acl/users' }) // 登录后跳转到用户列表页面
		},
		logout() {
			this.mobile = ''
			this.email = ''
			this.userName = ''
			this.fullName = ''
			this.password = ''
			this.permissions = []
			this.roles = []
			this.sex = 'FEMALE'
			this.token = ''
			this.refreshToken = ''
			router.push({ path: '/login/user' }) // 退出登录后跳转到登录页面，未实现，要清理缓存？
		},
	},
	persist: {
		key: 'user',
		storage: localStorage,
	},
})
